### Machine Learning for Physical Sciences (mlphys)
Author: [Sanjaya Lohani](https://sanjayalohani.com)  

Email: slohani@mlphys.com

### Installation
```pip install mlphys```


### API
* <a href="https://github.com/slohani-ai/machine-learning-for-physical-sciences/tree/main/mlphys/deepqis">deepQis</a>

* <a href="https://github.com/slohani-ai/machine-learning-for-physical-sciences/tree/main/mlphys/lgoam">LG-OAM Tensors</a>
<!--
Thanks to [Brian T. Kirby](https://briankirby.github.io/), [Ryan T. Glasser](http://www.tulane.edu/~rglasser97/), [Sean D. Huver](https://developer.nvidia.com/blog/author/shuver/) and [Thomas A. Searles](https://ece.uic.edu/profiles/searles-thomas/)
-->
<!--
### Follow me:

[Twitter](https://twitter.com/slohani_ai) 
-->